aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/python/VppConfigGenerator.py
diff options
context:
space:
mode:
authorpmikus <pmikus@cisco.com>2020-09-18 09:46:31 +0000
committerPeter Mikus <pmikus@cisco.com>2020-09-22 11:36:27 +0000
commit636c8c711b5f44cd0ef7c4a04a4b3bc0aad6566d (patch)
tree18b62c93776b1128b272793bc7a2724700835e4d /resources/libraries/python/VppConfigGenerator.py
parent3f75897c4f79f0eec83d69a49bb14ae7ecb784de (diff)
Framework: Heapsize configuration
- https://gerrit.fd.io/r/c/vpp/+/28829 - https://gerrit.fd.io/r/c/vpp/+/28896 - ip6 to be added later Signed-off-by: pmikus <pmikus@cisco.com> Change-Id: I7b03b8ace5c5c7582d4a2f66bfd788a3ec80a916
Diffstat (limited to 'resources/libraries/python/VppConfigGenerator.py')
-rw-r--r--resources/libraries/python/VppConfigGenerator.py31
1 files changed, 20 insertions, 11 deletions
diff --git a/resources/libraries/python/VppConfigGenerator.py b/resources/libraries/python/VppConfigGenerator.py
index 68a4e22e6b..fa8290d974 100644
--- a/resources/libraries/python/VppConfigGenerator.py
+++ b/resources/libraries/python/VppConfigGenerator.py
@@ -419,13 +419,22 @@ class VppConfigGenerator:
path = [u"cpu", u"corelist-workers"]
self.add_config_item(self._nodeconfig, value, path)
- def add_heapsize(self, value):
- """Add Heapsize configuration.
+ def add_main_heap_size(self, value):
+ """Add Main Heap Size configuration.
- :param value: Amount of heapsize.
+ :param value: Amount of heap.
:type value: str
"""
- path = [u"heapsize"]
+ path = [u"memory", u"main-heap-size"]
+ self.add_config_item(self._nodeconfig, value, path)
+
+ def add_main_heap_page_size(self, value):
+ """Add Main Heap Page Size configuration.
+
+ :param value: Heap page size.
+ :type value: str
+ """
+ path = [u"memory", u"main-heap-page-size"]
self.add_config_item(self._nodeconfig, value, path)
def add_api_trace(self):
@@ -451,22 +460,22 @@ class VppConfigGenerator:
path = [u"ip6", u"heap-size"]
self.add_config_item(self._nodeconfig, value, path)
- def add_ip_heap_size(self, value):
- """Add IP heap-size configuration.
+ def add_statseg_size(self, value):
+ """Add Stats Heap Size configuration.
- :param value: IP Heapsize amount.
+ :param value: Stats heapsize amount.
:type value: str
"""
- path = [u"ip", u"heap-size"]
+ path = [u"statseg", u"size"]
self.add_config_item(self._nodeconfig, value, path)
- def add_statseg_size(self, value):
- """Add stats segment heap size configuration.
+ def add_statseg_page_size(self, value):
+ """Add Stats Heap Page Size configuration.
:param value: Stats heapsize amount.
:type value: str
"""
- path = [u"statseg", u"size"]
+ path = [u"statseg", u"page-size"]
self.add_config_item(self._nodeconfig, value, path)
def add_statseg_per_node_counters(self, value):